@@ -13,12 +13,12 @@ use crate::{
         Confidence, Finding, Fix, Severity,
         location::{Comment, Feature, Location, Routable},
     },
-    github_api,
+    github,
     models::{StepCommon, action::CompositeStep, uses::RepositoryUsesExt, workflow::Step},
 };
 
 pub(crate) struct RefVersionMismatch {
-    client: github_api::Client,
+    client: github::Client,
 }
 
 audit_meta!(
@@ -27,6 +27,7 @@ audit_meta!(
     "detects commit SHAs that don't match their version comment tags"
 );
 
+#[allow(clippy::unwrap_used)]
 static VERSION_COMMENT_PATTERNS: LazyLock<Vec<Regex>> = LazyLock::new(|| {
     vec![
         // Matches "# tag=v2.8.0" or "# tag=v1.2.3"
@@ -239,16 +240,15 @@ jobs:
             "fakegroup".into(),
             "test_version_mismatch.yml",
             None::<&str>,
-        )
-        .unwrap();
+        );
         let workflow = Workflow::from_string(workflow_content.to_string(), key).unwrap();
 
         let state = crate::state::AuditState::new(
             false,
             Some(
-                github_api::Client::new(
-                    &github_api::GitHubHost::default(),
-                    &github_api::GitHubToken::new(&std::env::var("GH_TOKEN").unwrap()).unwrap(),
+                github::Client::new(
+                    &github::GitHubHost::default(),
+                    &github::GitHubToken::new(&std::env::var("GH_TOKEN").unwrap()).unwrap(),
                     "/tmp".into(),
                 )
                 .unwrap(),
@@ -311,16 +311,15 @@ jobs:
             "fakegroup".into(),
             "test_different_formats.yml",
             None::<&str>,
-        )
-        .unwrap();
+        );
         let workflow = Workflow::from_string(workflow_content.to_string(), key).unwrap();
 
         let state = crate::state::AuditState::new(
             false,
             Some(
-                github_api::Client::new(
-                    &github_api::GitHubHost::default(),
-                    &github_api::GitHubToken::new(&std::env::var("GH_TOKEN").unwrap()).unwrap(),
+                github::Client::new(
+                    &github::GitHubHost::default(),
+                    &github::GitHubToken::new(&std::env::var("GH_TOKEN").unwrap()).unwrap(),
                     "/tmp".into(),
                 )
                 .unwrap(),
