@@ -798,7 +798,7 @@ jobs:
 
         let workflow = Workflow::from_string(
             workflow.into(),
-            crate::InputKey::local("fakegroup".into(), "dummy", None)?,
+            crate::InputKey::local("fakegroup".into(), "dummy", None),
         )?;
 
         // `foo` unifies in favor of the more permissive capability,
